@@ -20,18 +20,15 @@
 #include "bus-watch-namespace.h"
 #include <gio/gio.h>
 
-G_DEFINE_TYPE (MprisController, mpris_controller, G_TYPE_OBJECT)
-
-#define CONTROLLER_PRIVATE(o) \
-  (G_TYPE_INSTANCE_GET_PRIVATE ((o), MPRIS_TYPE_CONTROLLER, MprisControllerPrivate))
-
 enum {
   PROP_0,
   PROP_HAS_ACTIVE_PLAYER
 };
 
-struct _MprisControllerPrivate
+struct _MprisController
 {
+  GObject parent;
+
   GCancellable *cancellable;
   GDBusProxy *mpris_client_proxy;
   guint namespace_watcher_id;
@@ -39,27 +36,28 @@ struct _MprisControllerPrivate
   gboolean connecting;
 };
 
+G_DEFINE_TYPE (MprisController, mpris_controller, G_TYPE_OBJECT)
 
 static void mpris_player_try_connect (MprisController *self);
 
 static void
 mpris_controller_dispose (GObject *object)
 {
-  MprisControllerPrivate *priv = MPRIS_CONTROLLER (object)->priv;
+  MprisController *self = MPRIS_CONTROLLER (object);
 
-  g_clear_object (&priv->cancellable);
-  g_clear_object (&priv->mpris_client_proxy);
+  g_clear_object (&self->cancellable);
+  g_clear_object (&self->mpris_client_proxy);
 
-  if (priv->namespace_watcher_id)
+  if (self->namespace_watcher_id)
     {
-      bus_unwatch_namespace (priv->namespace_watcher_id);
-      priv->namespace_watcher_id = 0;
+      bus_unwatch_namespace (self->namespace_watcher_id);
+      self->namespace_watcher_id = 0;
     }
 
-  if (priv->other_players)
+  if (self->other_players)
     {
-      g_slist_free_full (priv->other_players, g_free);
-      priv->other_players = NULL;
+      g_slist_free_full (self->other_players, g_free);
+      self->other_players = NULL;
     }
 
   G_OBJECT_CLASS (mpris_controller_parent_class)->dispose (object);
@@ -86,18 +84,16 @@ mpris_proxy_call_done (GObject      *object,
 gboolean
 mpris_controller_key (MprisController *self, const gchar *key)
 {
-  MprisControllerPrivate *priv = MPRIS_CONTROLLER (self)->priv;
-
-  if (!priv->mpris_client_proxy)
+  if (!self->mpris_client_proxy)
     return FALSE;
 
   if (g_strcmp0 (key, "Play") == 0)
     key = "PlayPause";
 
   g_debug ("calling %s over dbus to mpris client %s",
-           key, g_dbus_proxy_get_name (priv->mpris_client_proxy));
-  g_dbus_proxy_call (priv->mpris_client_proxy,
-                     key, NULL, 0, -1, priv->cancellable,
+           key, g_dbus_proxy_get_name (self->mpris_client_proxy));
+  g_dbus_proxy_call (self->mpris_client_proxy,
+                     key, NULL, 0, -1, self->cancellable,
                      mpris_proxy_call_done,
                      NULL);
   return TRUE;
@@ -115,7 +111,7 @@ mpris_client_notify_name_owner_cb (GDBusProxy      *proxy,
   if (name_owner)
     return;
 
-  g_clear_object (&self->priv->mpris_client_proxy);
+  g_clear_object (&self->mpris_client_proxy);
   g_object_notify (G_OBJECT (self), "has-active-player");
 
   mpris_player_try_connect (self);
@@ -126,7 +122,7 @@ mpris_proxy_ready_cb (GObject      *object,
                       GAsyncResult *res,
                       gpointer      user_data)
 {
-  MprisControllerPrivate *priv;
+  MprisController *self = MPRIS_CONTROLLER (object);
   GError *error = NULL;
   GDBusProxy *proxy;
 
@@ -138,7 +134,7 @@ mpris_proxy_ready_cb (GObject      *object,
         {
           g_warning ("Error connecting to mpris interface %s", error->message);
 
-          priv->connecting = FALSE;
+          self->connecting = FALSE;
 
           mpris_player_try_connect (MPRIS_CONTROLLER (user_data));
         }
@@ -146,9 +142,8 @@ mpris_proxy_ready_cb (GObject      *object,
       return;
     }
 
-  priv = MPRIS_CONTROLLER (user_data)->priv;
-  priv->mpris_client_proxy = proxy;
-  priv->connecting = FALSE;
+  self->mpris_client_proxy = proxy;
+  self->connecting = FALSE;
 
   g_signal_connect (proxy, "notify::g-name-owner",
                     G_CALLBACK (mpris_client_notify_name_owner_cb), user_data);
@@ -159,8 +154,6 @@ mpris_proxy_ready_cb (GObject      *object,
 static void
 start_mpris_proxy (MprisController *self, const gchar *name)
 {
-  MprisControllerPrivate *priv = MPRIS_CONTROLLER (self)->priv;
-
   g_debug ("Creating proxy for for %s", name);
   g_dbus_proxy_new_for_bus (G_BUS_TYPE_SESSION,
                             0,
@@ -168,31 +161,30 @@ start_mpris_proxy (MprisController *self, const gchar *name)
                             name,
                             "/org/mpris/MediaPlayer2",
                             "org.mpris.MediaPlayer2.Player",
-                            priv->cancellable,
+                            self->cancellable,
                             mpris_proxy_ready_cb,
                             self);
-  priv->connecting = TRUE;
+  self->connecting = TRUE;
 }
 
 static void
 mpris_player_try_connect (MprisController *self)
 {
-  MprisControllerPrivate *priv = MPRIS_CONTROLLER (self)->priv;
   GSList *first;
   gchar *name;
 
-  if (priv->connecting || priv->mpris_client_proxy)
+  if (self->connecting || self->mpris_client_proxy)
     return;
 
-  if (!priv->other_players)
+  if (!self->other_players)
     return;
 
-  first = priv->other_players;
+  first = self->other_players;
   name = first->data;
 
   start_mpris_proxy (self, name);
 
-  priv->other_players = priv->other_players->next;
+  self->other_players = self->other_players->next;
   g_free (name);
   g_slist_free_1 (first);
 }
@@ -204,9 +196,8 @@ mpris_player_appeared (GDBusConnection *connection,
                        gpointer         user_data)
 {
   MprisController *self = user_data;
-  MprisControllerPrivate *priv = MPRIS_CONTROLLER (self)->priv;
 
-  priv->other_players = g_slist_prepend (priv->other_players, g_strdup (name));
+  self->other_players = g_slist_prepend (self->other_players, g_strdup (name));
   mpris_player_try_connect (self);
 }
 
@@ -216,13 +207,12 @@ mpris_player_vanished (GDBusConnection *connection,
                        gpointer         user_data)
 {
   MprisController *self = user_data;
-  MprisControllerPrivate *priv = MPRIS_CONTROLLER (self)->priv;
   GSList *elem;
 
-  elem = g_slist_find_custom (priv->other_players, name, (GCompareFunc) g_strcmp0);
+  elem = g_slist_find_custom (self->other_players, name, (GCompareFunc) g_strcmp0);
   if (elem)
     {
-      priv->other_players = g_slist_remove_link (priv->other_players, elem);
+      self->other_players = g_slist_remove_link (self->other_players, elem);
       g_free (elem->data);
       g_slist_free_1 (elem);
     }
@@ -231,9 +221,9 @@ mpris_player_vanished (GDBusConnection *connection,
 static void
 mpris_controller_constructed (GObject *object)
 {
-  MprisControllerPrivate *priv = MPRIS_CONTROLLER (object)->priv;
+  MprisController *self = MPRIS_CONTROLLER (object);
 
-  priv->namespace_watcher_id = bus_watch_namespace (G_BUS_TYPE_SESSION,
+  self->namespace_watcher_id = bus_watch_namespace (G_BUS_TYPE_SESSION,
                                                     "org.mpris.MediaPlayer2",
                                                     mpris_player_appeared,
                                                     mpris_player_vanished,
@@ -265,8 +255,6 @@ mpris_controller_class_init (MprisControllerClass *klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-  g_type_class_add_private (klass, sizeof (MprisControllerPrivate));
-
   object_class->constructed = mpris_controller_constructed;
   object_class->dispose = mpris_controller_dispose;
   object_class->get_property = mpris_controller_get_property;
@@ -283,7 +271,6 @@ mpris_controller_class_init (MprisControllerClass *klass)
 static void
 mpris_controller_init (MprisController *self)
 {
-  self->priv = CONTROLLER_PRIVATE (self);
 }
 
 gboolean
@@ -291,7 +278,7 @@ mpris_controller_get_has_active_player (MprisController *controller)
 {
   g_return_val_if_fail (MPRIS_IS_CONTROLLER (controller), FALSE);
 
-  return (controller->priv->mpris_client_proxy != NULL);
+  return (controller->mpris_client_proxy != NULL);
 }
 
 MprisController *
